from .models import SandboxAgentCredentials

# Utility Companies (🇧🇷 Concessionárias) data from CCEE staging environment
UTILITIES: list[SandboxAgentCredentials] = [
    # First batch: 100000-100009
    SandboxAgentCredentials("CONCESSIONARIA_100000", "cIuCKVUWZjdUJhuPdU1G6QhMNg3ROGcn", 100000, [100000]),
    SandboxAgentCredentials("CONCESSIONARIA_100001", "rNX5erkcWqsqzSLaohe34dCKHMTZkUxV", 100001, [100001]),
    SandboxAgentCredentials("CONCESSIONARIA_100002", "KamX78ehm7gYnBB93iPQadFtbEqgY2Du", 100002, [100002]),
    SandboxAgentCredentials("CONCESSIONARIA_100003", "yF0Bs8s1cycovGU4OeIFtfxTs2Mff4Jk", 100003, [100003]),
    SandboxAgentCredentials("CONCESSIONARIA_100004", "EgSorhAzwkTDzwzJM91t6erybLqx6QDr", 100004, [100004]),
    SandboxAgentCredentials("CONCESSIONARIA_100005", "VlTDTGebZ2I4U8zYKphmsRqu9mmFIeTR", 100005, [100005]),
    SandboxAgentCredentials("CONCESSIONARIA_100006", "L3Jwo9DoFs7WVCv3a112jvfOCDOK0hKy", 100006, [100006]),
    SandboxAgentCredentials("CONCESSIONARIA_100007", "IYg2IxMcinTphLIEY0gI5sV6Qw3iNwhU", 100007, [100007]),
    SandboxAgentCredentials("CONCESSIONARIA_100008", "qM060fxODg5k8ybGTO9RdQRZZrhO0HWK", 100008, [100008]),
    SandboxAgentCredentials("CONCESSIONARIA_100009", "502n7ZVxN8KEcWSq7oUZjIykcJE7bgOb", 100009, [100009]),
    # Second batch: 400000-400019
    SandboxAgentCredentials("CONCESSIONARIA_400000", "d09b0161-014c-4736-91d8-95a231fa9184", 400000, [400000]),
    SandboxAgentCredentials("CONCESSIONARIA_400001", "589e7f32-7e9d-4f83-8a2c-d0b2bf3ec618", 400001, [400001]),
    SandboxAgentCredentials("CONCESSIONARIA_400002", "bbeb156d-bc49-4a1e-96f0-3593b7bda6d5", 400002, [400002]),
    SandboxAgentCredentials("CONCESSIONARIA_400003", "04504093-e7a1-4bd7-b5ee-d808cd373b69", 400003, [400003]),
    SandboxAgentCredentials("CONCESSIONARIA_400004", "9b993e70-502e-4e1a-8cae-aea0cfdf6fa9", 400004, [400004]),
    SandboxAgentCredentials("CONCESSIONARIA_400005", "17bf7230-f526-41ff-a23a-cf401e28b558", 400005, [400005]),
    SandboxAgentCredentials("CONCESSIONARIA_400006", "3781fc16-0e25-4b8a-bf11-58a492410d49", 400006, [400006]),
    SandboxAgentCredentials("CONCESSIONARIA_400007", "b5a6ab13-9ab8-413f-baf9-31e120629006", 400007, [400007]),
    SandboxAgentCredentials("CONCESSIONARIA_400008", "f509c48f-ec36-4b19-a290-47bce6d81f73", 400008, [400008]),
    SandboxAgentCredentials("CONCESSIONARIA_400009", "26bfa7f2-6aec-440a-9fe5-7cf42756ee29", 400009, [400009]),
    SandboxAgentCredentials("CONCESSIONARIA_400010", "23e01bfd-c17e-42ca-9dd1-4c6a20271210", 400010, [400010]),
    SandboxAgentCredentials("CONCESSIONARIA_400011", "47dc3455-652a-4a9e-bf7f-71e08a7c7fbb", 400011, [400011]),
    SandboxAgentCredentials("CONCESSIONARIA_400012", "ab905add-c0e8-4e2d-bd9f-70db17361711", 400012, [400012]),
    SandboxAgentCredentials("CONCESSIONARIA_400013", "b27035b1-28a8-45e7-8eb4-f9b968ceb9de", 400013, [400013]),
    SandboxAgentCredentials("CONCESSIONARIA_400014", "3d9d311c-15ae-4bd0-b851-40afd6c10e8d", 400014, [400014]),
    SandboxAgentCredentials("CONCESSIONARIA_400015", "e3709b66-f5ed-490f-9a7c-b9d63b354ea4", 400015, [400015]),
    SandboxAgentCredentials("CONCESSIONARIA_400016", "adf4fe77-5649-413f-a052-c04da5f1945b", 400016, [400016]),
    SandboxAgentCredentials("CONCESSIONARIA_400017", "e5d85e71-56a1-46a7-a30b-276168515541", 400017, [400017]),
    SandboxAgentCredentials("CONCESSIONARIA_400018", "e83b43ed-2949-40d4-87eb-f827a34ed43f", 400018, [400018]),
    SandboxAgentCredentials("CONCESSIONARIA_400019", "af3e0b5f-8d6d-4148-9658-749a0db02945", 400019, [400019]),
]
